@@ -1,25 +1,39 @@
 package GD::SecurityImage;
+$GD::SecurityImage::VERSION = '1.75';
 use strict;
-use vars qw[@ISA $AUTOLOAD $VERSION $BACKEND];
+use warnings;
+use vars qw[@ISA $BACKEND];
 use GD::SecurityImage::Styles;
 use Carp qw(croak);
+use constant RGB_WHITE   => ( 255, 255, 255 );
+use constant RGB_BLACK   => ( 0, 0, 0 );
+use constant RANDOM_DATA => ( 0..9 );
+use constant FULL_CIRCLE => 360;
+use constant DEFAULT_ANGLES => (0,5,8,15,22,26,29,33,35,36,40,43,45,53,56);
 
-$VERSION = '1.66';
+use constant DEFAULT_WIDTH  => 80;
+use constant DEFAULT_HEIGHT => 30;
+use constant DEFAULT_PTSIZE => 20;
+use constant DEFAULT_LINES  => 10;
+
+use constant MAX_RGB_VALUE  => 255;
+use constant PARTICLE_MULTIPLIER => 20;
+use constant MAX_RGB_PARAMS => 3;
 
 sub import {
-   my $class   = shift;
-   my %opt     = scalar(@_) % 2 ? () : (@_);
+   my($class, @args) = @_;
+   my %opt     = @args % 2 ? () : @args;
    # init/reset globals
-   $BACKEND    = ''; # name of the back-end
-   @ISA        = ();
+   $BACKEND    = q{}; # name of the back-end
+   @ISA        = (); ## no critic (ClassHierarchies::ProhibitExplicitISA)
    # load the drawing interface
    if ( exists $opt{use_magick} && $opt{use_magick} ) {
       require GD::SecurityImage::Magick;
       $BACKEND = 'Magick';
    }
    elsif ( exists $opt{backend} && $opt{backend} ) {
-      my $be = __PACKAGE__.'::'.$opt{backend};
-      eval "require $be";
+      my $be  = __PACKAGE__.q{::}.$opt{backend};
+      my $eok = eval "require $be";
       croak "Unable to locate the $class back-end $be: $@" if $@;
       $BACKEND = $opt{backend} eq 'AC' ? 'GD' : $opt{backend};
    }
@@ -27,15 +41,15 @@ sub import {
       require GD::SecurityImage::GD;
       $BACKEND = 'GD';
    }
-   push @ISA, 'GD::SecurityImage::' . $BACKEND;
-   push @ISA, qw(GD::SecurityImage::Styles); # load styles
+   push @ISA, 'GD::SecurityImage::' . $BACKEND, ## no critic (ClassHierarchies::ProhibitExplicitISA)
+              qw(GD::SecurityImage::Styles); # load styles
    return;
 }
 
 sub new {
-   my $class = shift;
+   my($class, @args) = @_;
       $BACKEND || croak "You didn't import $class!";
-   my %opt   = scalar @_ % 2 ? () : (@_);
+   my %opt   = @args % 2 ? () : @args;
 
    my $self  = {
       IS_MAGICK       => $BACKEND eq 'Magick',
@@ -44,7 +58,7 @@ sub new {
       DISABLED        => {}, # list of methods that a backend (or some older version of backend) can't do
       MAGICK          => {}, # Image::Magick configuration options
       GDBOX_EMPTY     => 0,  # GD::SecurityImage::GD::insert_text() failed?
-      _RANDOM_NUMBER_ => '', # random security code
+      _RANDOM_NUMBER_ => q{}, # random security code
       _RNDMAX_        => 6,  # maximum number of characters in a random string.
       _COLOR_         => {}, # text and line colors
       _CREATECALLED_  => 0,  # create() called? (check for particle())
@@ -52,50 +66,40 @@ sub new {
    };
    bless $self, $class;
 
-   my %options = (
-      width      => $opt{width}               || 80,
-      height     => $opt{height}              || 30,
-      ptsize     => $opt{ptsize}              || 20,
-      lines      => $opt{lines}               || 10,
-      rndmax     => $opt{rndmax}              || $self->{_RNDMAX_},
-      rnd_data   => $opt{rnd_data}            || [0..9],
-      font       => $opt{font}                || '',
-      gd_font    => $self->gdf($opt{gd_font}) || '',
-      bgcolor    => $opt{bgcolor}             || [255, 255, 255],
-      send_ctobg => $opt{send_ctobg}          || 0,
-      frame      => defined($opt{frame}) ? $opt{frame} : 1,
-      scramble   => $opt{scramble}            || 0,
-      angle      => $opt{angle}               || 0,
-      thickness  => $opt{thickness}           || 0,
-      _ANGLES_   => [], # angle list for scrambled images
-   );
+   my %options = $self->_new_options( %opt );
 
-   if($opt{text_location} && ref $opt{text_location} && ref $opt{text_location} eq 'HASH') {
+   if ( $opt{text_location}
+      && ref $opt{text_location}
+      && ref $opt{text_location} eq 'HASH' ) {
       $self->{_TEXT_LOCATION_} = { %{$opt{text_location}}, _place_ => 1 };
    }
    else {
       $self->{_TEXT_LOCATION_}{_place_} = 0;
    }
-   $self->{_RNDMAX_} = $options{rndmax}; 
+
+   $self->{_RNDMAX_} = $options{rndmax};
 
    $self->{$_} = $options{$_} foreach keys %options;
-   if($self->{angle}) { # validate angle
-      $self->{angle} = 360 + $self->{angle} if $self->{angle} < 0;
-      if($self->{angle} > 360) {
-         croak "Angle parameter can take values in the range -360..360";
+
+   if ( $self->{angle} ) { # validate angle
+      $self->{angle} = FULL_CIRCLE + $self->{angle} if $self->{angle} < 0;
+      if ( $self->{angle} > FULL_CIRCLE ) {
+         croak 'Angle parameter can take values in the range -360..360';
       }
    }
 
-   if ($self->{scramble}) {
-      if ($self->{angle}) {
+   if ( $self->{scramble} ) {
+      if ( $self->{angle} ) {
          # Does the user want a fixed angle?
          push @{ $self->{_ANGLES_} }, $self->{angle};
       }
       else {
          # Generate angle range. The reason for hardcoding these is; 
          # it'll be less random for 0..60 range
-         push @{ $self->{_ANGLES_} }, (0,5,8,15,22,26,29,33,35,36,40,43,45,53,56);
-         push @{ $self->{_ANGLES_} }, map {360 - $_} @{ $self->{_ANGLES_} }; # push negatives
+         push @{ $self->{_ANGLES_} }, DEFAULT_ANGLES;
+         # push negatives
+         push @{ $self->{_ANGLES_} },
+              map {FULL_CIRCLE - $_} @{ $self->{_ANGLES_} };
       }
    }
 
@@ -103,42 +107,66 @@ sub new {
    return $self;
 }
 
+sub _new_options {
+   my($self, %opt) = @_;
+   my %options = (
+      width      => $opt{width}               || DEFAULT_WIDTH,
+      height     => $opt{height}              || DEFAULT_HEIGHT,
+      ptsize     => $opt{ptsize}              || DEFAULT_PTSIZE,
+      lines      => $opt{lines}               || DEFAULT_LINES,
+      rndmax     => $opt{rndmax}              || $self->{_RNDMAX_},
+      rnd_data   => $opt{rnd_data}            || [ RANDOM_DATA ],
+      font       => $opt{font}                || q{},
+      gd_font    => $self->gdf($opt{gd_font}) || q{},
+      bgcolor    => $opt{bgcolor}             || [ RGB_WHITE ],
+      send_ctobg => $opt{send_ctobg}          || 0,
+      frame      => defined($opt{frame}) ? $opt{frame} : 1,
+      scramble   => $opt{scramble}            || 0,
+      angle      => $opt{angle}               || 0,
+      thickness  => $opt{thickness}           || 0,
+      _ANGLES_   => [], # angle list for scrambled images
+   );
+   return %options;
+}
+
 sub backends {
    my $self  = shift;
    my $class = ref($self) || $self;
    my(@list, @dir_list);
+   require Symbol;
    foreach my $inc (@INC) {
       my $dir = "$inc/GD/SecurityImage";
       next unless -d $dir;
-      local  *DIR;
-      opendir DIR, $dir or croak "opendir($dir) failed: $!";
-      my @dir = readdir DIR;
-      closedir DIR;
+      my $DIR = Symbol::gensym();
+      opendir $DIR, $dir or croak "opendir($dir) failed: $!";
+      my @dir = readdir $DIR;
+      closedir $DIR;
       push @dir_list, $dir;
       foreach my $file (@dir) {
          next if -d $file;
-         next if $file =~ m[^\.];
-         next if $file =~ m[^(Styles|AC|Handler)\.pm$];
-         $file =~ s[\.pm$][];
+         next if $file =~ m{ \A [.] }xms;
+         next if $file =~ m{ \A (Styles|AC|Handler)[.]pm \z}xms;
+         $file =~ s{ [.]pm \z}{}xms;
          push @list, $file;
       }
    }
-   if (defined wantarray) {
-      return @list;
-   }
-   else {
-      print "Available back-ends in $class v$VERSION are:\n\t"
-            .join("\n\t", @list)
-            ."\n\n"
-            ."Search directories:\n\t"
-            .join("\n\t", @dir_list);
-   }
+
+   return @list if defined wantarray;
+
+   my $version = $self->VERSION;
+   my $report = "Available back-ends in $class v$version are:\n\t"
+               . join("\n\t", @list)
+               . "\n\n"
+               . "Search directories:\n\t"
+               . join "\n\t", @dir_list;
+   print $report or croak "Unable to print to STDOUT: $!";
+   return;
 }
 
 sub gdf {
-   my $self = shift;
+   my($self, @args) = @_;
    return if not $self->{IS_GD};
-   return $self->gdfx(@_);
+   return $self->gdfx( @args );
 }
 
 sub random_angle {
@@ -149,7 +177,7 @@ sub random_angle {
    return $r[int rand @r];
 }
 
-sub random_str { shift->{_RANDOM_NUMBER_} }
+sub random_str { return shift->{_RANDOM_NUMBER_} }
 
 sub random {
    my $self = shift;
@@ -164,24 +192,24 @@ sub random {
          $random .= $keys[int rand $lk] for 1..$self->{rndmax};
          $self->{_RANDOM_NUMBER_} = $random;
    }
-   return $self if defined wantarray;
+   return defined wantarray ? $self : undef;
 }
 
 sub cconvert { # convert color codes
    # GD           : return color index number
    # Image::Magick: return hex color code
    my $self   = shift;
-   my $data   = shift || croak "Empty parameter passed to cconvert!";
+   my $data   = shift || croak 'Empty parameter passed to cconvert';
    return $self->backend_cconvert($data) if not $self->{IS_CORE};
 
    my $is_hex    = $self->is_hex($data);
    my $magick_ok = $self->{IS_MAGICK} && $data && $is_hex;
    # data is a hex color code and Image::Magick has hex support
    return $data if $magick_ok;
-   my $color_code = $data              &&
-                    ! $is_hex          &&
-                    ! ref($data)       &&
-                    $data !~ m{[^0-9]} &&
+   my $color_code = $data                 &&
+                    ! $is_hex             &&
+                    ! ref($data)          &&
+                    $data !~ m{[^0-9]}xms &&
                     $data >= 0;
 
    if( $color_code ) {
@@ -195,15 +223,20 @@ sub cconvert { # convert color codes
    }
 
    my @rgb = $self->h2r($data);
-   return $data if @rgb && $self->{IS_MAGICK};
+   return @rgb && $self->{IS_MAGICK}
+         ? $data
+         : $self->_cconvert_new( $data, @rgb );
+}
 
+sub _cconvert_new {
+   my($self, $data, @rgb) = @_;
    $data = [@rgb] if @rgb;
    # initialize if not valid
-   if(not $data || not ref $data || ref $data ne 'ARRAY' || $#{$data} != 2) {
+   if(! $data || ! ref $data || ref $data ne 'ARRAY' || $#{$data} != 2) {
       $data = [0, 0, 0];
    }
    foreach my $i (0..$#{$data}) { # check for bad values
-      if ($data->[$i] > 255 or $data->[$i] < 0) {
+      if ( $data->[$i] > MAX_RGB_VALUE || $data->[$i] < 0 ) {
          $data->[$i] = 0;
       }
    }
@@ -225,12 +258,7 @@ sub create {
         lines => $self->cconvert($col2),
    };
 
-   # be a smart module and auto-disable ttf if we are under a prehistoric GD
-   if ( not $self->{IS_MAGICK} ) {
-      $method = 'normal' if $self->_versionlt(1.20);
-   }
-
-   if($method eq 'normal' and not $self->{gd_font}) {
+   if ( $method eq 'normal' && ! $self->{gd_font} ) {
       $self->{gd_font} = $self->gdf('giant');
    }
 
@@ -248,37 +276,36 @@ sub create {
    }
 
    $self->{_CREATECALLED_}++;
-   return $self if defined wantarray;
+   return defined wantarray ? $self : undef;
 }
 
 sub particle {
    # Create random dots. They'll cover all over the surface
    my $self = shift;
-   croak "particle() must be called 'after' create()" if not $self->{_CREATECALLED_};
+   croak q{particle() must be called 'after' create()} if !$self->{_CREATECALLED_};
    my $big  = $self->{height} > $self->{width} ? $self->{height} : $self->{width};
-   my $f    = shift || $big * 20; # particle density
+   my $f    = shift || $big * PARTICLE_MULTIPLIER; # particle density
    my $dots = shift || 1; # number of multiple dots
-   my $int  = int $big / 20;
+   my $int  = int $big / PARTICLE_MULTIPLIER;
 
    if ( ! $int ) { # RT#33629
-      warn "particle(): image dimension is so small to add particles";
+      warn "particle(): image dimension is so small to add particles\n";
       return;
    }
 
    my @random;
-   for (my $x = $int; $x <= $big; $x += $int) {
+   for (my $x = $int; $x <= $big; $x += $int) { ## no critic (ControlStructures::ProhibitCStyleForLoops)
       push @random, $x;
    }
 
    my $tc  = $self->{_COLOR_}{text};
    my $len = @random;
    my $r   = sub { $random[ int rand $len ] };
-   my($x, $y, $z);
 
-   for (1..$f) {
-      $x = int rand $self->{width};
-      $y = int rand $self->{height};
-      foreach $z (1..$dots) {
+   for ( 1..$f ) {
+      my $x = int rand $self->{width};
+      my $y = int rand $self->{height};
+      foreach my $z (1..$dots) {
          $self->setPixel($x + $z         , $y + $z         , $tc);
          $self->setPixel($x + $z + $r->(), $y + $z + $r->(), $tc);
       }
@@ -286,10 +313,10 @@ sub particle {
    undef @random;
    undef $r;
 
-   return $self if defined wantarray;
+   return defined wantarray ? $self : undef;
 }
 
-sub raw { $_[0]->{image} } # raw image object
+sub raw { return shift->{image} } # raw image object
 
 sub info_text { # set text location
    # x      => 'left|right',  # text-X
@@ -300,34 +327,49 @@ sub info_text { # set text location
    # color  => '#000000',     # text color
    # scolor => '#FFFFFF',     # strip color
    # text   => 'blah',        # modifies random code
-   my $self = shift;
-   croak "info_text() must be called 'after' create()" if not $self->{_CREATECALLED_};
-   my %o = scalar(@_) % 2 ? () : ( qw/ x right y up strip 1 /, @_ );
+   my($self, @args) = @_;
+   croak q{info_text() must be called 'after' create()} if ! $self->{_CREATECALLED_};
+   my %o = @args % 2 ? () : ( qw/ x right y up strip 1 /, @args );
    return if not %o;
 
    $self->{_TEXT_LOCATION_}{_place_} = 1;
    $o{scolor}                        = $self->cconvert($o{scolor})       if $o{scolor};
-   local $self->{_RANDOM_NUMBER_}    = delete $o{text}                   if $o{text};
-   local $self->{_COLOR_}{text}      = $self->cconvert(delete $o{color}) if $o{color};
-   local $self->{ptsize}             = delete $o{ptsize}                 if $o{ptsize};
 
-   local $self->{scramble} = 0; # disable. we need a straight text
-   local $self->{angle}    = 0; # disable. RT:14618
+   my %restore = (
+      random   => $self->{_RANDOM_NUMBER_},
+      color    => $self->{_COLOR_}{text},
+      ptsize   => $self->{ptsize},
+      scramble => $self->{scramble},
+      angle    => $self->{angle},
+   );
+
+   $self->{_RANDOM_NUMBER_}    = delete $o{text}                   if $o{text};
+   $self->{_COLOR_}{text}      = $self->cconvert(delete $o{color}) if $o{color};
+   $self->{ptsize}             = delete $o{ptsize}                 if $o{ptsize};
+   $self->{scramble}           = 0; # disable. we need a straight text
+   $self->{angle}              = 0; # disable. RT:14618
 
    $self->{_TEXT_LOCATION_}->{$_} = $o{$_} foreach keys %o;
    $self->insert_text('ttf');
-   $self;
+
+   # restore
+   $self->{_RANDOM_NUMBER_}    = $restore{random};
+   $self->{_COLOR_}{text}      = $restore{color};
+   $self->{ptsize}             = $restore{ptsize};
+   $self->{scramble}           = $restore{scramble};
+   $self->{angle}              = $restore{angle};
+
+   return $self;
 }
 
 #--------------------[ PRIVATE ]--------------------#
 
 sub add_strip { # adds a strip to the background of the text
-   my $self = shift;
-   my($x, $y, $box_w, $box_h) = @_;
+   my($self, $x, $y, $box_w, $box_h) = @_;
    my $tl    = $self->{_TEXT_LOCATION_};
    my $c     = $self->{_COLOR_} || {};
-   my $black = $self->cconvert( $c->{text}    ? $c->{text}    : [   0,   0,   0 ] );
-   my $white = $self->cconvert( $tl->{scolor} ? $tl->{scolor} : [ 255, 255, 255 ] );
+   my $black = $self->cconvert( $c->{text}    ? $c->{text}    : [ RGB_BLACK ] );
+   my $white = $self->cconvert( $tl->{scolor} ? $tl->{scolor} : [ RGB_WHITE ] );
    my $x2    = $tl->{x} eq 'left' ? $box_w : $self->{width};
    my $y2    = $self->{height} - $box_h;
    my $i     = $self->{IS_MAGICK} ? $self  : $self->{image};
@@ -340,11 +382,11 @@ sub add_strip { # adds a strip to the background of the text
 
 sub r2h {
    # Convert RGB to Hex
-   my $self = shift;
-   @_ == 3 || return;
-   my $color  = '#';
-      $color .= sprintf("%02x", $_) foreach @_;
-      $color;
+   my($self, @args) = @_;
+   return if @args != MAX_RGB_PARAMS;
+   my $color  = q{#};
+      $color .= sprintf '%02x', $_ foreach @args;
+   return $color;
 }
 
 sub h2r {
@@ -352,58 +394,59 @@ sub h2r {
    my $self  = shift;
    my $color = shift;
    return if ref $color;
-   my @rgb   = $color =~ m[^#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})$]i;
+   my @rgb   = $color =~ m/\A \#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2}) \z/xmsi;
    return @rgb ? map { hex $_ } @rgb : undef;
 }
 
 sub is_hex {
    my $self = shift;
    my $data = shift;
-   return $data =~ m[^#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})$]i;
+   return $data =~ m/ \A \#([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2}) \z /xmsi;
 }
 
-sub AUTOLOAD {
-   my $self  = shift;
-   my $class = ref $self;
-   (my $name = $AUTOLOAD) =~ s,.*:,,;
-   # fake method for GD compatibility. only GD has this
-   return 0 if $name eq 'gdbox_empty';
-   croak "Unknown $class method '$name'";
-}
-
-sub DESTROY {}
-
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-GD::SecurityImage - Security image (captcha) generator.
+GD::SecurityImage
+
+=head1 VERSION
+
+version 1.75
 
 =head1 SYNOPSIS
 
    use GD::SecurityImage;
 
    # Create a normal image
-   my $image = GD::SecurityImage->new(width   => 80,
-                                      height  => 30,
-                                      lines   => 10,
-                                      gd_font => 'giant');
-      $image->random($your_random_str);
-      $image->create(normal => 'rect');
+   my $image = GD::SecurityImage->new(
+                  width   => 80,
+                  height  => 30,
+                  lines   => 10,
+                  gd_font => 'giant',
+               );
+      $image->random( $your_random_str );
+      $image->create( normal => 'rect' );
    my($image_data, $mime_type, $random_number) = $image->out;
 
 or
 
    # use external ttf font
-   my $image = GD::SecurityImage->new(width    => 100,
-                                      height   => 40,
-                                      lines    => 10,
-                                      font     => "/absolute/path/to/your.ttf",
-                                      scramble => 1);
-      $image->random($your_random_str);
-      $image->create(ttf => 'default');
+   my $image = GD::SecurityImage->new(
+                  width    => 100,
+                  height   => 40,
+                  lines    => 10,
+                  font     => "/absolute/path/to/your.ttf",
+                  scramble => 1,
+               );
+      $image->random( $your_random_str );
+      $image->create( ttf => 'default' );
       $image->particle;
    my($image_data, $mime_type, $random_number) = $image->out;
 
@@ -454,6 +497,10 @@ If you are an user of one of these frameworks, see
 L</"GD::SecurityImage Implementations"> in L</"SEE ALSO"> section
 for information.
 
+=head1 NAME
+
+GD::SecurityImage - Security image (captcha) generator.
+
 =head1 COLOR PARAMETERS
 
 This module can use both RGB and HEX values as the color 
@@ -517,7 +564,7 @@ Set this parameter if you want to use ttf in your image.
 
 =item gd_font
 
-If you want to use the default interface, set this paramater. The 
+If you want to use the default interface, set this parameter. The
 recognized values are C<Small>, C<Large>, C<MediumBold>, C<Tiny>, C<Giant>.
 The names are case-insensitive; you can pass lower-cased parameters.
 
@@ -569,8 +616,8 @@ The minimum length of the random string. Default value is C<6>.
 =item rnd_data
 
 Default character set used to create the random string is C<0..9>.
-But, if you want to use letters also, you can set this paramater.
-This paramater takes an array reference as the value.
+But, if you want to use letters also, you can set this parameter.
+This parameter takes an array reference as the value.
 
 B<Not necessary and will not be used if you pass your own random>
 B<string.>
@@ -597,8 +644,7 @@ none are mandatory.
 
 C<$method> can be B<C<normal>> or B<C<ttf>>.
 
-C<$style> can be one of the following (some of the styles may not work 
-if you are using a really old version of GD):
+C<$style> can be one of the following:
 
 =over 4
 
@@ -637,9 +683,6 @@ Draws nothing. See L</"OTHER USES">.
 
 =back
 
-I<Note>: if you have a (too) old version of GD, you may not be able 
-to use some of the styles.
-
 You can use this code to get all available style names:
 
    my @styles = grep {s/^style_//} keys %GD::SecurityImage::Styles::;
@@ -679,7 +722,7 @@ This method must be called after L<create|/create>. If you call it
 early, you'll die. C<info_text> adds an extra text to the generated 
 image. You can also put a strip under the text. The purpose of this 
 method is to display additional information on the image. Copyright 
-informations can be an example for that. 
+information can be an example for that.
 
    $image->info_text(
       x      => 'right',
@@ -722,7 +765,7 @@ parameter passed to C<new> will be used instead.
 =item ptsize
 
 The ptsize value of the information text to be used with the TTF font.
-TTF font paramter can not be set with C<info_text()>. The value passed
+TTF font parameter can not be set with C<info_text()>. The value passed
 to C<new()> will be used instead.
 
 =item color
@@ -743,9 +786,7 @@ long texts, be sure to adjust the image, or clipping will occur.
 =head2 out
 
 This method finally returns the created image, the mime type of the 
-image and the random number(s) generated. Older versions of GD only support
-C<gif> type, while new versions support C<jpeg> and C<png> 
-(B<update>: beginning with v2.15, GD resumed gif support).
+image and the random number(s) generated.
 
 The returned mime type is C<png> or C<gif> or C<jpeg> for C<GD> and 
 C<gif> for C<Image::Magick> (if you do not C<force> some other format).
@@ -808,7 +849,7 @@ or the raw C<Image::Magick> object:
    my $magick = $image->raw;
    $magick->Write("gif:-");
 
-Can be usefull, if you want to modify the graphic yourself. If you 
+Can be useful, if you want to modify the graphic yourself. If you
 want to get an I<image type> see the C<force> option in C<out>.
 
 =head2 gdbox_empty
@@ -816,6 +857,20 @@ want to get an I<image type> see the C<force> option in C<out>.
 See L</"path bug"> in L</"GD bug"> for usage and other information 
 on this method.
 
+=head2 add_strip
+
+=head2 cconvert
+
+=head2 gdf
+
+=head2 h2r
+
+=head2 is_hex
+
+=head2 r2h
+
+=head2 random_angle
+
 =head1 UTILITY METHODS
 
 =head2 backends
@@ -861,8 +916,6 @@ this mandatory methods.
    ellipse		draws an ellipse
    arc			draws an arc
    setThickness		sets the thickness of the lines when drawing something
-   _versiongt           backend version is greater or equal to supplied param?
-   _versionlt           backend version is smaller than supplied param?
 
 and
 
@@ -890,160 +943,9 @@ C<GD::SecurityImage>.
 Download the distribution from a CPAN mirror near you, if you 
 don't have the files.
 
-=begin html
+Running the test suite will also create some sample images.
 
-<!-- this h1 part is for search.cpan.org -->
-<h1>
-<a class = 'u' 
-   href  = '#___top'
-   title ='click to go to top of document'
-   name  = "IMAGE SAMPLES"
->IMAGE SAMPLES</a>
-</h1>
-
-<p>
-All TTF samples generated with the bundled font <i>StayPuft.ttf</i>,
-unless stated otherwise. Most of the samples here can be generated with 
-running the test suite that comes with the GD::SecurityImage distribution. 
-However, images that are generated with random angles will indeed be a 
-little different after you run the test suite on your system.
-</p>
-
-<p>
-All random codes have a length of six (6) characters, unless stated otherwise.
-So, (for example) there is no clipping in <code>ELLIPS</code>.
-</p>
-
-<table border      = "1"
-       cellpadding = "4"
-       cellspacing = "1"
->
-   <tr>
-      <td colspan="2" style="text-align:center;font-weight:bold">
-         <br />
-         Images generated with GD
-         <br />
-         <br />
-      </td>
-   </tr>
-
-   <tr><td colspan="2">&#160;</td></tr>
-
-   <tr>
-      <td> Standard interface. Font: <b>gdGiantFont</b> </td>
-      <td> Style: <b>rect</b>                           </td>
-   </tr>
-   <tr>
-      <td><img border="0" src="http://img505.imageshack.us/img505/1365/gdnormal03boxvi9.png" /></td>
-      <td><img border="0" src="http://img524.imageshack.us/img524/9065/gdttf02rectiz2.png"   /></td>
-   </tr>
-
-   <tr><td colspan="2">&#160;</td></tr>
-
-   <tr>
-      <td>Style: <b>rect</b>. Scrambled with random angles.</td>
-      <td>Style: <b>circle</b>. Scrambled with a fixed angle.</td>
-   </tr>
-   <tr>
-      <td><img border="0" src="http://img505.imageshack.us/img505/8893/gdttfscramble02rectma0.png" /></td>
-      <td><img border="0" src="http://img512.imageshack.us/img512/8207/gdttfscramblefixed04cirwt1.png" /></td>
-   </tr>
-
-   <tr><td colspan="2">&#160;</td></tr>
-
-   <tr>
-      <td>Style: <b>default</b>. Scrambled with a fixed angle. <br />Info text at the top right.</td>
-      <td>Style: <b>circle</b>. Scrambled with random angles. <br />Font is: <i>Transformers.ttf</i></td>
-   </tr>
-   <tr>
-      <td><img border="0" src="http://img524.imageshack.us/img524/1452/gdttfscramblefixedinfotuz9.png"  /></td>
-      <td><img border="0" src="http://img505.imageshack.us/img505/739/differentdz6.png" /></td>
-   </tr>
-
-</table>
-
-<p>&nbsp;</p>
-
-<table border      = "1"
-       cellpadding = "4"
-       cellspacing = "2"
->
-   <tr>
-      <td colspan="2" style="text-align:center;font-weight:bold">
-         <br />
-         Images generated with Image::Magick
-         <br />
-         <br />
-      </td>
-   </tr>
-
-   <tr><td colspan="2">&#160;</td></tr>
-
-   <tr>
-      <td>Style: <b>circle</b>.</td>
-      <td>Style: <b>box</b>. Scrambled with random angles.</td>
-   </tr>
-   <tr>
-      <td><img border="0" src="http://img524.imageshack.us/img524/1233/magick04circleru3.png"       /></td>
-      <td><img border="0" src="http://img521.imageshack.us/img521/7235/magickscramble03boxmb2.png" /></td>
-   </tr>
-
-   <tr><td colspan="2">&#160;</td></tr>
-   <tr>
-      <td>Style: <b>circle</b>. Scrambled with a fixed angle.</td>
-      <td>Style: <b>ellipse</b>. Scrambled with a fixed angle.<br /> Info text at the top right.</td>
-   </tr>
-
-   <tr>
-      <td><img border="0" src="http://img139.imageshack.us/img139/7227/magickscramblefixed04cihd4.png" /></td>
-      <td><img border="0" src="http://img440.imageshack.us/img440/2647/magickscramblefixed05elnz6.png" /></td>
-   </tr>
-
-   <tr><td colspan="2">&#160;</td></tr>
-
-   <tr>
-      <td>Style: <b>ec</b>. Scrambled with random angles.<br /> Info text at the top right.</td>
-      <td>Style: <b>ec</b>. Scrambled with random angles<b><sup>1</sup>.</b></td>
-   </tr>
-   <tr>
-      <td><img border="0" src="http://img139.imageshack.us/img139/9587/magickscrambleinfotext0bz8.png" /></td>
-      <td><img border="0" src="http://img505.imageshack.us/img505/347/burakrw7.gif" /></td>
-   </tr>
-
-</table>
-
-
-<p>
-<sup><b>1</b></sup>: This image is generated with this code:</p>
-<p>
-<pre>
-<span style="color: #8B008B; font-weight:bold;">use</span> <span style="color: #000000;">GD::SecurityImage</span> <span style="color: #000000;">backend</span> <span style="color: #000000;">=&gt;</span> <span style="color: #CD5555;">'Magick'</span><span style="color: #000000;">;</span>
-<span style="color: #8B008B; font-weight:bold;">my</span><span style="color: #000000;">(</span><span style="color: #00688B;">$data</span><span style="color: #000000;">,</span> <span style="color: #00688B;">$mime</span><span style="color: #000000;">,</span> <span style="color: #00688B;">$rnd</span><span style="color: #000000;">)</span> = <span style="color: #000000;">GD::SecurityImage</span>
-<span style="color: #000000;">-&gt;new</span><span style="color: #000000;">(</span>
-   <span style="color: #000000;">width</span>      <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">420</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">height</span>     <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">100</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">ptsize</span>     <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">40</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">lines</span>      <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">20</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">thickness</span>  <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">4</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">rndmax</span>     <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">5</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">scramble</span>   <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">1</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">send_ctobg</span> <span style="color: #000000;">=&gt;</span> <span style="color: #B452CD;">1</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">bgcolor</span>    <span style="color: #000000;">=&gt;</span> <span style="color: #CD5555;">'#009999'</span><span style="color: #000000;">,</span>
-   <span style="color: #000000;">font</span>       <span style="color: #000000;">=&gt;</span> <span style="color: #CD5555;">'StayPuft.ttf'</span><span style="color: #000000;">,</span>
-<span style="color: #000000;">)</span>
-<span style="color: #00688B;">-&gt;random</span><span style="color: #000000;">(</span><span style="color: #CD5555;">'BURAK'</span><span style="color: #000000;">)</span>
-<span style="color: #00688B;">-&gt;create</span><span style="color: #000000;">(</span> <span style="color: #CD5555;">qw/ ttf ec #0066CC #0066CC /</span> <span style="color: #000000;">)</span>
-<span style="color: #00688B;">-&gt;particle</span><span style="color: #000000;">(</span><span style="color: #B452CD;">300</span><span style="color: #000000;">,</span> <span style="color: #B452CD;">500</span><span style="color: #000000;">)</span>
-<span style="color: #00688B;">-&gt;out</span><span style="color: #000000;">;</span>
-
-</pre>
-</p>
-
-<p>Images hosted by <a href="http://imageshack.us">ImageShack</a>.</p>
-
-=end html
-
-=head2 OTHER USES
+=head2 OTHER USE CASES
 
 C<GD::SecurityImage> drawing capabilities can also be used for 
 I<counter image> generation or displaying arbitrary messages:
@@ -1087,21 +989,6 @@ I<counter image> generation or displaying arbitrary messages:
    print header -type => "image/$mime";
    print $data;
 
-=begin html
-
-<p>
-The generated graphic will be:
-<br/>
-<br/>
-<img src    = "http://img101.imageshack.us/img101/4770/gdsicountered2.png"
-     border = "0"
-     alt    = "Image Hosted by ImageShack.us" />
-</p>
-
-<p>Image hosted by <a href="http://imageshack.us">ImageShack</a>.</p>
-
-=end html
-
 =head1 ERROR HANDLING
 
 C<die> is called in some methods if something fails. You may need to 
@@ -1130,19 +1017,6 @@ may prevent this.
 See the L</SUPPORT> section if you have a bug or 
 request to report.
 
-=head2 Image::Magick bug
-
-There is a bug in PerlMagick' s C<QueryFontMetrics()> method. ImageMagick
-versions smaller than 6.0.4 is affected. Below text is from the ImageMagick 
-6.0.4 Changelog: L<http://www.imagemagick.org/www/Changelog.html>.
-
-"2004-05-06 PerlMagick's C<QueryFontMetrics()> incorrectly reports `unrecognized 
-attribute'` for the `font' attribute."
-
-Please upgrade to ImageMagick 6.0.4 or any newer version, if your ImageMagick 
-version is smaller than 6.0.4 and you want to use Image::Magick as the backend
-for GD::SecurityImage.
-
 =head2 GD bug
 
 =head3 path bug
@@ -1241,33 +1115,6 @@ The internal random code generator is used B<only> for demonstration
 purposes for this module. It may not be I<effective>. You must supply 
 your own random code and use this module to display it.
 
-=item *
-
-B<[GD] png compression>
-
-Support for compression level argument to png() added in v2.07. If
-your GD version is smaller than this, compress option to C<out()>
-will be silently ignored.
-
-=item *
-
-B<[GD] setThickness>
-
-setThickness implemented in GD v2.07. If your GD version is smaller
-than that and you set thickness option, nothing will happen.
-
-=item *
-
-B<[GD] ellipse>
-
-C<ellipse()> method added in GD 2.07. 
-
-If your GD version is smaller than 2.07 and you use C<ellipse>, 
-the C<default> style will be returned.
-
-If your GD is smaller than 2.07 and you use C<ec>, only the circles will
-be drawn.
-
 =back
 
 =head1 SEE ALSO
@@ -1323,7 +1170,7 @@ L<Catalyst::Plugin::Captcha>
 
 =item *
 
-L<CGI::Application::Plugin::CAPTCHA >
+L<CGI::Application::Plugin::CAPTCHA>
 
 =item *
 
@@ -1331,44 +1178,15 @@ L<Angerwhale::Controller::Captcha>
 
 =back
 
-=head2 Software Using GD::SecurityImage
-
-If your software uses C<GD::SecurityImage> for captcha generation and
-want to appear in this document, contact the author.
-
-=head1 SUPPORT
-
-=head2 BUG REPORTS
-
-All bug reports and wishlist items B<must> be reported via
-the CPAN RT system. It is accessible at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=GD-SecurityImage>.
-
-=head2 DISCUSSION FORUM
-
-C<CPAN::Forum> is a place for discussing C<CPAN>
-modules. It also has a C<GD::SecurityImage> section at
-L<http://www.cpanforum.com/dist/GD-SecurityImage>.
-
-=head2 RATINGS
-
-If you like or hate or have some suggestions about
-C<GD::SecurityImage>, you can comment/rate the distribution via 
-the C<CPAN Ratings> system: 
-L<http://cpanratings.perl.org/dist/GD-SecurityImage>.
-
 =head1 AUTHOR
 
-Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 Burak GE<252>rsoy. All rights reserved.
+This software is copyright (c) 2004 by Burak Gursoy.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.8.8 or, 
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
